/**************************************************************************
**   FILE NAME		: lldp_mib_intf.h
**   PROJECT		: Inca-Ip
**   MODULES	    : LLDP
**   SRC VERSION	: V1.0
**
**   DATE			:12-04-2007
**   AUTHOR			:Supreet M S, Pavan G M, Awanish G
**   DESCRIPTION	:Source file 	
**   COMPILER		:GCC
**   REFERENCE		:Coding Guideline Version 2.0
**							
**   COPYRIGHT      :Copyright © 2004
**                   Infineon Technologies AG
**                   St. Martin Strasse 53; 81669 München, Germany
**   DESCLAIMER     :Any use of this Software is subject to the conclusion 
**                   of a respective License Agreement.
**                   Without such a License Agreement no rights to the 
**         			 Software are granted. 
**
**  Version Control Section 
**   $Author$
**   $Date$
**   $Revisions$
**   $Log$       Revision history
***********************************************************************/

#ifndef __IFX_LLDP_MIB_INTF_H__
#define __IFX_LLDP_MIB_INTF_H__

#define LLDP_MIB_TELEPHONE 0x20
#define MAXNETWORKTLVS IFX_LLDP_MAXNETWORKTLVS

typedef enum
{
   MIB_FAIL = -1,
   MIB_SUCCESS = 0,
   MIB_NOSP_HANDLING
}respType;

/* This structure stores the Chassis ID information 
		which has to be updated in the MIB */
struct ChassisId {
	uint8 subType;
	uint8 chassisId[255];
};

/* This structure stores the Port ID information 
		which has to be updated in the MIB */
struct PortId {
	uint8 subType;
	uint8 portId[255];
}; 

/* This structure stores the System Capabilities TLV 
		related information which has to be updated in the MIB */
struct Sys_capabilities {
	uint16 sys_capabilities;
	uint16 enabled_capabilities;
};

/* This structure stores the MAC/PHY Configuration/Status TLV 
		related information which has to be updated in the MIB */
struct MacPhy_configStatus {
	uint8 autoNegSupported;
	uint8 autoNegEnabled;
	uint16 autoNegAdvCap;
	uint16 operMauType;
};

/* This structure stores the LLDP-MED Capabilities TLV 
		related information which has to be updated in the MIB */
struct MedCapabilities {
	uint16 capSupported;
	uint8 deviceType;
};

/* This structure stores the Network Policy TLV related 
		information which has to be updated in the MIB */
struct NetworkPolicyTlv {
 	uint8 appType;
	boolean unknownFlag;
	boolean taggedFlag;
	uint16 vLanId;
	uint8 priority;
	uint8 dscpValue;	
};

/* This structure stores all Network Policy TLV values */
struct NetworkPolicy {
  uint8 noOfNetworkPolicyTlvs;
  struct NetworkPolicyTlv network_policy_array[MAXNETWORKTLVS];
};

struct LocationIdentification {
    uint8 dataFormat;
    uint8 locationId[256];
};

/* This structure stores the Extended Power-via-MDI TLV 
		related information which has to be updated in the MIB */
struct ExtendedPower {
	uint8 powerType;
	uint8 powerSource;
	uint8 powerPriority;
	uint16 powerValue;
};

/* This structure stores the Port VLAN ID TLV related 
		information which has to be updated in the MIB */
struct PortVlanId {
	uint16 portVlanId;
};

/* This structure stores the Port And Protocol VLAN ID TLV related 
		information which has to be updated in the MIB */
struct PortAndProtocolVlanId {
  uint8 protoVlanSupported;
  uint8 protoVlanEnabled;
	uint16 protoVlanId;
};

/* This structure stores the VLAN Name TLV related 
		information which has to be updated in the MIB */
struct VlanName {
  uint16 vlanId;
  uint8 vlanNameLength;
	uint8 vlanName[32];
};

/* This structure stores the Protocol Identity TLV related 
		information which has to be updated in the MIB */
struct ProtocolIdentity {
  uint8 protoIdLength;
  uint8 protoId[255];
};

/* This enum defines all the capabilities 
		that define the primary function(s) of the system */
enum systemCapabilities {
	none = 0,
	repeater,
	bridge,
	wlanAccessPoint,
	router,
	telephone,
	docsisCableDevice,
	stationOnly	
};
/* This enum defines all possible PMD auto-negotiation 
		advertised capabilities used in /PHY Configuration/Status TLV */
enum ifMauAutoNegCapAdvertisedBits {
	bother =0,
	b10baseT,
	b10baseTFD,
	b100baseT4,
	b100baseTX,
	b100baseTXFD,
	b100baseT2,
	b100baseT2FD,
	bFdxPause,
	bFdxAPause,
	bFdxSPause,
	bFdxBPause,
	b1000baseX,
	b1000baseXFD,
	b1000baseT,
	b1000baseTFD
};
/* This enum defines values that indicates whether the sender 
		is a Network Connectivity Device or Endpoint Device, 
		and if an Endpoint, which Endpoint Class it belongs to */
enum deviceType {
	notDefined =0,
	classI,
	classII,
	classIII,
	networkConnectivity
};

/* This enum value represents whether LLDP-MED device transmitting 
		the LLDPDU is a Power Sourcing Entity (PSE) or Power Device (PD) */
enum extendedPowerType {
	pseDevice =0,
	pdDevice,
	powerTypeReserved
};

/* This enum value represents the power source being utilized by a PD device */
enum extendedPowerPdSource {
	pdSourceUnknown =0,
	pse,
	local,
	pseAndLocal
};

/* This enum value represents the power source being utilized by a PSE device */
enum extendedPowerPseSource {
	pseSourceUnknown =0,
	primary,
	backup,
	reserved
};

/* This enum value represents the priority of the PD type device */
enum extendedPowerPriority {
	powerPriorityUnknown =0,
	critical,
	high,
	low,
	priorityReserved
};


/* This enum value represents whether Local System MIB 
	or Remote System MIB is being accessed */
enum lldpMibType {
	localConfig =0,
	localTlvSel,
	Stats,
	localMib,
	remoteMibMsap,
	remoteMibMac,
	rawFrame,
  remotemac,
	miscellaneousCfg,
	maxInfoTypes
};

enum lldpAdminStatus {
  lldpEnabledTxOnly =0,
  lldpEnabledRxOnly,
  lldpEnabledRxTx,
  lldpDisabled
};

/*This holds the bit map of supported TLV's*/
enum lldptlv
{
  CHASSIS_ID   		       = 1,
  PORT_ID 		       = 2,
  SYSTEM_CAPABILITIES 	       = 4,
  TIME_TO_LIVE 		       = 8,
  PORT_VLAN_ID 		       = 0x10,
  PORT_AND_PROTOCOL_VLAN_ID    = 0x20,
  VLAN_NAME 		       = 0x40,
  PROTOCOL_IDENTITY 	       = 0x80,
  MAC_PHY_CONFIGURATION_STATUS = 0x100,
  MED_CAPABILITIES             = 0x200,
  NETWORK_POLICY               = 0x400,
  LOCATION_IDENTIFICATION      = 0x2000,
  EXTENDED_POWER_VIA_MDI       = 0x800,
  END_OF_LLDPDU                =0x1000
};

/* This structure represents a complete Local System MIB 
	or any one Remote System MIB */
struct LldpMib {
	struct ChassisId chassis_id;
	struct PortId port_id;	
	struct Sys_capabilities sys_cap;
  struct PortVlanId port_vlan_id;
  struct PortAndProtocolVlanId port_proto_vlan;
  struct VlanName vlan_name;
  struct ProtocolIdentity proto_id;
	struct MacPhy_configStatus mac_phy;
	struct MedCapabilities med_cap;	
	struct NetworkPolicy network_policy;
	struct LocationIdentification location_identification;
	struct ExtendedPower ext_power;
}; 

/* This structure represents LLDP configure data 
	which has to be stored in the MIB */
struct LldpConfigMib {
	uint8 adminStatus;
	uint16 reinitDelay;
  	uint16 msgTxHold;
  	uint16 msgTxInterval;
  	uint16 txDelay;
	uint32 medFastStartRepeatCount;
}; 

/* This structure represents LLDP Basic TLV Selection 
	data which has to be stored in the MIB */
struct LldpTlvSelectionMib {
	uint32 portConfigTlvTxEnable;
	uint16 ManAddrPortsTxEnable;
}; 

/* This structure represents LLDP statistics data 
	which has to be stored in the MIB */
struct LldpStatsMib {
	uint32 statsAgeoutsTotal;
 	uint32 statsFramesDiscardedTotal;
	uint32 statsFramesInErrorsTotal;
	uint32 statsFramesInTotal;
	uint32 statsFramesOutTotal;
	uint32 statsTLVsDiscardedTotal;
	uint32 statsTLVsUnrecognizedTotal;
}; 

struct MiscellaneousCfg{
  uint32 ConfigRemoteEntries;
  uint32 CurrRemoteEntries;
};

/* Interface functions */


/* This function gets the values of all TLV.s 
	from either local or remote system MIB based on the input parameters */
uint8 getMibData(uint8 info_type,uint8 intf_index, char8 *msap, void *return_data);

/* This function either sets the values of all TLV.s of the local system MIB 
	or adds a new remote system MIB to the remote system MIB table 
	based on the input parameters */
uint8 setMibData( uint8 info_type,uint8 intf_index, char8 *msap, void *input_data);

/* This function deletes a remote system MIB entry from the Remote system MIB table */
uint8 deleteMibData(uint8 intf_index, char8 *msap);

#endif /* __IFX_LLDP_MIB_INTF_H__ */
