#ifndef LLDP_RX_MODULE_H
#define LLDP_RX_MODULE_H

struct lldp_event;
struct lldp_port;

/*This data type contains all possible receive timers*/
struct lldp_rx_port_timers {
  uint16 tooManyNeighborsTimer;
  uint32 rxTTL;
};

/*This data type defines all possible receive module statistics*/
struct lldp_rx_port_statistics {
  uint32 statsAgeoutsTotal;
  uint32 statsFramesDiscardedTotal;
  uint32 statsFramesInErrorsTotal;
  uint32 statsFramesInTotal;
  uint32 statsTLVsDiscardedTotal;
  uint32 statsTLVsUnrecognizedTotal;
};

struct lldp_rx_msaptimermap {
  uint16 uiTimerID; /*Timer ID returned by the Timer I/f for a particular msap*/
  uint8 *Msap;
  uint8 *Mac;
};

/*contains all the information related to the Receive module*/
typedef struct {
  uint8 *frame;
  ssize_t recvsize;
  uint8 state;
  uint8 currstate;
  uint8 badFrame;
  uint8 rcvFrame;
  uint8 rxInfoAge;
  uint8 rxChanges;
  uint8 somethingChangedRemote;
  uint8 tooManyNeighbors;
  struct lldp_rx_port_timers timers;
  struct lldp_rx_port_statistics statistics;
  /*these 2 ll be updated in rxprocessframe.Intermediary storage till update info*/
  struct LldpMib LLDPRemoteMIB;
  uint8 *curr_recvmac;
  uint8 *curr_recvmsap;
  uint64 curr_msaplength;
  uint8 uiPresentMsap;
  int16 uiTempIndex;
  /*this stores all the new recv msap and associated TimerID */
  //struct lldp_rx_msaptimermap *MsapTimer[IFX_LLDP_MAX_REMOTE_MIB_PER_PORT];
} lldp_rx_port;




/* Defined by the 802.1AB specification */

/* This function deletes an entry for a remote entity LLDP data from the 
   remote LLDP MIB */
uint8 mibDeleteObjects(struct lldp_port *lldp_port);

/* This function updates the remote LLDP MIB with respect to a received
   remote LLDPDU */
uint8 mibUpdateObjects(struct lldp_port *lldp_port);

/* This function initializes the receive module */
uint8 rxInitializeLLDP(struct lldp_port *lldp_port);

/* This is the main function which is called to process a received LLDP
   frame */
int32 rxProcessFrame(struct lldp_port *lldp_port);

/* This function is called by the LLDP Main when select unblocks with
   data for receive module. The received event is passed to receive module
   using this function and respective actions on the occurred events are
   taken here */
void LLdp_rx_HandleEvent(uint16 uiPortIndex,x_IFX_LLDP_Lldp_Event *event);

/* This function updates RX MIB statistics in configuration module */
void LLdp_rx_UpdateMIBStats(struct lldp_port *lldp_port);

/* This function cleans up the receive module before shutdown */
int32 LLdp_rx_cleanup(struct lldp_port *lldp_port);

/* This function handles a shutdown request from LLDP Manager */
void LLDP_rx_HandleShutdownFrame(struct lldp_port *lldp_port);

#endif /* LLDP_RX_MODULE_H */
