/*******************************************************************
 *
 * OpenLLDP TX Statemachine Header
 *
 * Licensed under a dual GPL/Proprietary license.  
 * See LICENSE file for more info.
 * 
 * File: lldp_tx_sm.h
 * 
 * Authors: Terry Simons (terry.simons@gmail.com)
 *
 *******************************************************************/

/*! \file lldp_tx_sm.h
    \brief OpenLLDP TX Statemachine Header
    
    This header file contains declarations, variables, and defines 
    specific to the OpenLLDP transmit state machine.
*/

#ifndef LLDP_TX_SM_H
#define LLDP_TX_SM_H

#define LLDP_DEFAULT_PORT 1

struct lldp_port;

// States from the transmit state machine diagram (IEEE 802.1AB 10.5.4.3)

typedef enum{

  TX_LLDP_INITIALIZE = 0, 
  TX_IDLE,            
  TX_SHUTDOWN_FRAME,  
  TX_INFO_FRAME     
 
}lldp_tx_states; 

typedef enum{

  TX_LLDP_FRAME_INTERVAL_TIMEOUT = 101, //Interval b/w 2 LLDP frames
  TX_LLDP_LOCAL_MIB_CHANGES_TIMEOUT , //timer b/w 2 frames with changes
  TX_LLDP_SHUTDOWN_TIMEOUT  //timer for Tx shutdown
}lldp_tx_TimeoutID;

/****Utility functions*****/
/*this procedure stores the current state in the lldp port structure*/
inline void txChangeToState(struct lldp_port *lldp_port, uint8 state);

/*this procedure returns a string based on the current state of the Tx FSM*/
char *txStateFromID(uint8 state);

/*This procedure does the transition between states based on the satisfaction of prerequisite conditions*/
void txGlobalStatemachineRun(struct lldp_port *lldp_port);

/*This procedure performs actions based on the current state of the Tx FSM*/
void txStatemachineRun(struct lldp_port *lldp_port);

/*Transmit State machine procedures*/
void tx_do_tx_lldp_initialize(struct lldp_port *lldp_port);
void tx_do_tx_idle(struct lldp_port *lldp_port);
void tx_do_tx_info_frame(struct lldp_port *lldp_port);
void tx_display_timers(struct lldp_port *lldp_port);
void tx_do_tx_shutdown_frame(struct lldp_port *lldp_port);

//void tx_do_update_timers(struct lldp_port *lldp_port);
//void tx_do_tx_shutdown(struct lldp_port *lldp_port);
//STATIC uint16 min(uint16 value1, uint16 value2);
uint16 max(uint16 value1, uint16 value2);

#endif /* LLDP_TX_SM_H */
