/**************************************************************************
**   FILE NAME		: ifx_lldp_main.c
**   PROJECT		: Inca-Ip
**   MODULES	    : LLDP
**   SRC VERSION	: V1.0
**
**   DATE			:12-04-2007
**   AUTHOR			:Sanat. B,Pavan GM
**   DESCRIPTION	:Source file 	
**   COMPILER		:GCC
**   REFERENCE		:Coding Guideline Version 2.0
**							
**   COPYRIGHT      :Copyright © 2004
**                   Infineon Technologies AG
**                   St. Martin Strasse 53; 81669 München, Germany
**   DESCLAIMER     :Any use of this Software is subject to the conclusion 
**                   of a respective License Agreement.
**                   Without such a License Agreement no rights to the 
**         			 Software are granted. 
**
**  Version Control Section 
**   $Author$
**   $Date$
**   $Revisions$
**   $Log$       Revision history
***********************************************************************/

#include <errno.h>
#include <signal.h>             /* header for signal functions */

#include "ifx_common_defs.h"
#include "ifx_lldp_config.h"
#include "ifx_os.h"
#include "ifx_lldp_neighbor.h"
#include "ifx_lldp_tx_sm.h"
#include "ifx_lldp_rx_sm.h"
#include "ifx_lldp_mib_if.h"
#include "ifx_lldp_cm.h"
#include "ifx_lldp_rx_module.h"
#include "ifx_lldp_tx_module.h"
#include "ifx_lldp_port.h"
#include "ifx_lldp_tlv.h"
#include "ifx_lldp_local.h"
#include "ifx_lldp_timer_if.h"
#include "ifx_lldp_intf_defs.h"
#include "ifx_lldp_ms_if.h"
#include "ifx_lldp_timer_if.h"

EXTERN int32 viCmReadFd;/*reafFD of lldp FIFO which opened by CM after CMINIT*/
EXTERN int32 viNumPorts;/*being updated when LLDP_MODULE_INIT_MSG received from lldp manager*/

struct lldp_port *vpxlldp_port = NULL;
fd_set readfds,tmpreadfds;
fd_set writefds;
fd_set exceptfds;
int32 viMaxFd =0; 
const uint16 IFX_LLDP_MAX_TIMERS = 20;

/* SIGPIPE Signal Handler declaration */
void
IFX_LLDP_sigPipe(int32 iSigno, siginfo_t *pxsigInfo, void *context);

/* SIGPTERM/SIGSEGV Signal Handler declaration */
void
IFX_LLDP_sigTermOrSegv(int32 iSigno, siginfo_t *pxsigInfo, void *context);

void IFX_LLDP_FdSet(int32 soc)
{
	FD_SET(soc, &readfds);  
  if(soc > viMaxFd)
	{
		viMaxFd = soc + 1;
	}
}

int32 main()
{
   int32 iRet=0,i;
   int32 viReadFdTemp,viWriteFdTemp;
   struct sigaction xact;
   FD_ZERO(&readfds);
   FD_ZERO(&tmpreadfds);
   FD_ZERO(&writefds);
   FD_ZERO(&exceptfds);

	/*init number of timers required for lldp_agent*/
	if(IFX_LLDP_InitTimer(IFX_LLDP_MAX_TIMERS) < 0)
	{
		fprintf(stdout, "\n Timer Init failed. Exiting...\n");
		return -1;
	}

/* open FIFO for read */

  viReadFdTemp= IFX_OS_OpenFifo(IFX_LLDP_FIFO, O_RDONLY|O_NONBLOCK );
  if (viReadFdTemp < 0)
  {
      perror("[ERROR] IFX_OS_OpenFifo : ReadFd is - ");
      return -1;
  }

  /* open FIFO for write */

  viWriteFdTemp= IFX_OS_OpenFifo(IFX_LLDP_FIFO, O_WRONLY);
  if (viWriteFdTemp < 0)
  {
      perror("[ERROR] IFX_OS_OpenFifo : WriteFd is - ");
      return -1;
  }
  viCmReadFd= IFX_OS_OpenFifo(IFX_LLDP_FIFO, O_RDONLY );
  if (viCmReadFd < 0)
  {
      perror("error IFX_OS_OpenFifo : ReadFd is - ");
      return -1;
  }
	/*cm Init. LLDP FIFO created here*/
	if(IFX_LLDP_CM_Init() < 0)
	{
		PRINT("\n main ->IFX_LLDP_CM_Init : failed \n");
		return -1;
	}
  /* Interface with LLDP Manager initialization */
	if(IFX_LLDP_IntfInit() < 0)
	{
		fprintf(stdout, "\nLLDP Manager interface init failed. Exiting...\n");
		return -1;
	}

  IFX_OS_Close(viReadFdTemp);
  IFX_OS_Close(viWriteFdTemp);

    /*since after CM init FIFO read fd is valid*/
  IFX_LLDP_FdSet(viCmReadFd);

  /* Assign IFX_PA_AC_Mon_sigPipe function as our SIGPIPE handler */
  xact.sa_sigaction = IFX_LLDP_sigPipe;

  /* We don't want to block any other signals in this example */
  sigemptyset (&xact.sa_mask);

  /* We're only interested in children that have terminated, not ones
   * which have been stopped (eg user pressing control-Z at terminal)
   */
  xact.sa_flags = SA_NOCLDSTOP | SA_SIGINFO;

  /* Make these values effective. If we were writing a real
  * application, we would probably save the old value instead of 
  * passing NULL.
  */
  if (sigaction(SIGPIPE, &xact, NULL) < 0)
  {
    fprintf(stdout, "sigaction failed for SIGPIPE\n");
    return -1;
  }

  /* Assign IFX_PA_AC_Mon_sigTermOrSegv function as our SIGTERM/SIGSEGV 
     handler */
  xact.sa_sigaction = IFX_LLDP_sigTermOrSegv;

  /* We don't want to block any other signals in this example */
  sigemptyset (&xact.sa_mask);

  /* We're only interested in children that have terminated, not ones
   * which have been stopped (eg user pressing control-Z at terminal)
   */
  xact.sa_flags = SA_NOCLDSTOP | SA_SIGINFO;

  /* Make these values effective. If we were writing a real
  * application, we would probably save the old value instead of 
  * passing NULL.
  */
  if (sigaction(SIGTERM, &xact, NULL) < 0)
  {
    fprintf(stdout, "sigaction failed for SIGTERM\n");
    return -1;
  }
#if 0
  if (sigaction(SIGSEGV, &xact, NULL) < 0)
  {
    fprintf(stdout, "sigaction failed for SIGSEGV\n");
    return -1;
  }
#endif
	while(1)
	{				
  	memcpy(&tmpreadfds, &readfds, sizeof(fd_set));

		if((iRet = select(viMaxFd, &tmpreadfds, NULL, NULL,NULL)) < 0)
		{
			if(iRet == EINTR)
				continue;         
		}
		PRINT("\n main -> select unblocked\n");

		/*MSG on FIFO-TIMER or LLDP MGNR */
		if(FD_ISSET(viCmReadFd, &tmpreadfds))
		{
			PRINT("\n main -> select unblocked for local events\n");
			x_IFX_CM_Msg xCmMsg;
			memset(&xCmMsg,0,sizeof(x_IFX_CM_Msg));
			IFX_LLDP_CMFIFO_Read(&xCmMsg,sizeof(x_IFX_CM_Msg));

			IFX_LLDP_HandleLocalEvents(&xCmMsg);
		}

        /*check for all interface is there data on sockets??*/
		else if(vpxlldp_port != NULL)
		{
			for(i=0;i<viNumPorts;i++)
			{
				/*check for valid socket??*/
				if((vpxlldp_port+i)->socket != -1)
				{
					if(FD_ISSET((vpxlldp_port+i)->socket, &tmpreadfds))
					{
						PRINT("\nmain -> remote LLDP packet received\n");
						x_IFX_LLDP_Lldp_Event xLldpMsg;
						xLldpMsg.eEventType = LLDP_REMOTE_FRAME_MSG;
						LLdp_rx_HandleEvent(i,&xLldpMsg);
            break;
					}
				}
				
			}/*endof i for loop*/
		}
	}
	return 0;
}

/******************************************************************
*  Function Name    : IFX_LLDP_sigPipe
*  Description      : The signal handler function
*                     only gets called when a SIGPIPE is received,
*                     ie when a LLDP Manager is terminated
*  Input Values     : iSigno, sigingor and params
*  Output Values    : None
*  Return Value     : void
*  Notes            :
*********************************************************************/
void
IFX_LLDP_sigPipe(int32 iSigno, siginfo_t *pxsigInfo, void *context)
{
  /* Find and print the process name which has crashed */
  fprintf(stdout, "LLDP Manager terminated..\n");
}

/******************************************************************
*  Function Name    : IFX_LLDP_sigTermOrSegv
*  Description      : The signal handler function
*                     only gets called when a SIGTERM/SIGSEGV is 
*                     received, ie when a LLDP Manager is terminated
*  Input Values     : iSigno, sigingor and params
*  Output Values    : None
*  Return Value     : void
*  Notes            :
*********************************************************************/
void
IFX_LLDP_sigTermOrSegv(int32 iSigno, siginfo_t *pxsigInfo, void *context)
{
  /* Find and print the process name which has crashed */
  fprintf(stdout, "LLDP Agent received SIGTERM/SIGSEGV. Shutting Down...\n");
	IFX_LLDP_CM_SHM_Shut(); //delete shmem
  exit(0); //exit from the process gracefully
}
