/**************************************************************************
**   FILE NAME      : ifx_lldp_ms_intf.c
**   PROJECT        : Inca-Ip
**   MODULES        : LLDP
**   SRC VERSION    : V1.0
**
**   DATE           :26-04-2007
**   AUTHOR         :Awanish
**   DESCRIPTION    :Source file 	
**   COMPILER       :GCC
**   REFERENCE      :Coding Guideline Version 2.0
**							
**   COPYRIGHT      :Copyright © 2004
**                   Infineon Technologies AG
**                   St. Martin Strasse 53; 81669 München, Germany
**   DESCLAIMER     :Any use of this Software is subject to the conclusion 
**                   of a respective License Agreement.
**                   Without such a License Agreement no rights to the 
**                   Software are granted. 
**
**  Version Control Section 
**   $Author$
**   $Date$
**   $Revisions$
**   $Log$       Revision history
***********************************************************************/

#include "ifx_common_defs.h"
#include "ifx_lldp_config.h"
#include "ifx_lldp_intf_defs.h"
#include "ifx_os.h"
#include "ifx_lldp_ms_if.h"

int32 viWriteFd;

STATIC char8 IFX_LLDP_MsFifoWrite(void* pBuffer, uint32 uiSize);


/*****************************************************************************
*  Function Name        : IFX_LLDP_IntfInit
*  Description          : This fn Initializes the interface to LLDP manger
*  Input Values         : None.
*  Output Values        : None.
*  Return Value         : 0 on success,-1 on error
*  Notes                :
*****************************************************************************/

char8 IFX_LLDP_IntfInit()
{

  int32 iReadFdTemp;
  /*create a FIFO for LLDP*/
  if( IFX_OS_CreateFifo(IFX_LLDP_MS_FIFO) < 0 )
  {
	  perror("[ERROR] Error in IFX_OS_CreateFifo is - ");
  }

  /* open FIFO for read */

  iReadFdTemp= IFX_OS_OpenFifo(IFX_LLDP_MS_FIFO, O_RDONLY|O_NONBLOCK );
  if (iReadFdTemp < 0)
  {
      perror("[ERROR] IFX_OS_OpenFifo : ReadFd is - ");
      return -1;
  }

  /* open FIFO for write */

  viWriteFd = IFX_OS_OpenFifo(IFX_LLDP_MS_FIFO, O_WRONLY );
  if (viWriteFd < 0)
  {
      perror("[ERROR] IFX_OS_OpenFifo : WriteFd is - ");
      return -1;
  }
  IFX_OS_Close(iReadFdTemp);
  return 0;
}

/*****************************************************************************
*  Function Name        : IFX_LLDP_PACKET_RECEIVED
*  Description          : This fn intimates LLDP manager about packet reception
*  Input Values         : received pkt info
*  Output Values        : None.
*  Return Value         : 0 on success,-1 on error
*  Notes                :
*****************************************************************************/

char8 IFX_LLDP_PACKET_RECEIVED(x_IFX_LLDP_PACKET *pxLldpPacket)
{
  x_IFX_LLDP_LLDPAGENT_MSG xMsg;
  xMsg.eMsgType = IFX_LLDP_PACKET_RXVD_MSG;
  memcpy(&(xMsg.ux_Data.xPacket), pxLldpPacket, sizeof(x_IFX_LLDP_PACKET)); 
  return IFX_LLDP_MsFifoWrite(&xMsg, sizeof(x_IFX_LLDP_LLDPAGENT_MSG));
}

/*****************************************************************************
*  Function Name        : IFX_LLDP_PACKET_EXPIRED
*  Description          : This fn intimates LLDP manager about packet expiry
*  Input Values         : device type,mac addr
*  Output Values        : None.
*  Return Value         : 0 on success,-1 on error
*  Notes                :
*****************************************************************************/

char8 IFX_LLDP_PACKET_EXPIRED(e_IFX_LLDP_DEVICE_TYPE eDeviceType,
                              x_IFX_LLDP_MAC *pxMacAddress)
{
  x_IFX_LLDP_LLDPAGENT_MSG xMsg;
  xMsg.eMsgType = IFX_LLDP_PACKET_EXPIRED_MSG;
  xMsg.ux_Data.xPacketExpInfo.eDeviceType = eDeviceType;
  memcpy(&(xMsg.ux_Data.xPacketExpInfo.xMacAddress), pxMacAddress,
         sizeof(x_IFX_LLDP_MAC));
  return IFX_LLDP_MsFifoWrite(&xMsg, sizeof(x_IFX_LLDP_LLDPAGENT_MSG));

}

/*****************************************************************************
*  Function Name        : IFX_LLDP_MsFifoWrite
*  Description          : This fn writes data into LLDP manager fifo
*  Input Values         : data,size
*  Output Values        : None.
*  Return Value         : 0 on success,-1 on error
*  Notes                :
*****************************************************************************/

char8 IFX_LLDP_MsFifoWrite(void* pBuffer, uint32 uiSize)
{
  if(viWriteFd == 0)
  {
    PRINT("[ERROR] IFX_LLDP_MsFifoWrite : Writing to LLDP Manager FIFO Failed\n");
    return -1;
  }

  if(write(viWriteFd, pBuffer, uiSize) < 0)
  {
    perror("[ERROR] IFX_LLDP_MsFifoWrite : Error in LLDP Manager FIFO Write is:");
    return -1;
  }
  return 0;
}
