
/***********************************************************************
**   FILE NAME		: ifx_lldp_timer_if.c
**   PROJECT		: Inca-IP
**   MODULES	    : LLDP
**   SRC VERSION	: V1.0
**
**   DATE			:11-04-2007
**   AUTHOR			:sanat. B.
**   DESCRIPTION	:Timer Interface Function for LLDP.	
**   COMPILER		:GCC
**   REFERENCE		:Coding Guideline version 2.0.
**							
**   COPYRIGHT      :Copyright  2004
Infineon Technologies AG
St. Martin Strasse 53; 81669 Mnchen, Germany
**   DESCLAIMER     :Any use of this Software is subject to the conclusion 
of a respective License Agreement.
Without such a License Agreement no rights to the 
Software are granted. 
 
**  Version Control Section  **
**   $Author$
**   $Date$
**   $Revisions$
**   $Log$       Revision history
***********************************************************************/

#include "ifx_common_defs.h"
#include "ifx_os.h"
#include "ifx_lldp_cm.h"
#include "IFX_TLIB_Timlib.h"
#include "ifx_lldp_timer_if.h"

x_IFX_LLDP_Timer axLLDPTimer[IFX_LLDP_MAX_TIMER];

void IFX_LLDP_Timer_Handler(x_IFX_LLDP_Timer *pxLLDP_Param);

/******************************************************************
*  Function Name    : IFX_LLDP_StartTimer
*  Description      : This function will start the timer of given
value.
*  Input Values     :
*  Output Values    : None
*  Return Value     : int32
*  Notes            :
*********************************************************************/
int32
IFX_LLDP_StartTimer(uint32 uiTimerVal, x_IFX_LLDP_TimerCallBackParam *pxLLDP_Param,
                  uint16* punTimerID)
{
  int32 iRetVal = 0,iLoopVar;

  for (iLoopVar = 0; iLoopVar < IFX_LLDP_MAX_TIMER; iLoopVar++)

  {
    if (axLLDPTimer[iLoopVar].unTimerId == 0)

    {
      break;
    }
  }
  if (iLoopVar == IFX_LLDP_MAX_TIMER)

  {
    PRINT("\n LLDP Timer Exausted\n");
    return -1;
  }

  memcpy(&(axLLDPTimer[iLoopVar].xTimerParam),pxLLDP_Param,sizeof(x_IFX_LLDP_TimerCallBackParam));

  iRetVal = IFX_TLIB_StartTimer(punTimerID, uiTimerVal, 0,
                                 (void*) IFX_LLDP_Timer_Handler,
                                 &axLLDPTimer[iLoopVar]);
  if (iRetVal < 0)
  {
	PRINT("\n IFX_LLDP_StartTimer : failed \n");
  }

  axLLDPTimer[iLoopVar].unTimerId = *punTimerID;

  return iRetVal;
}


/******************************************************************
*  Function Name    : IFX_LLDP_StopTimer
*  Description      : This function will stop the timer.
*  Input Values     :
*  Output Values    : None
*  Return Value     : int32
*  Notes            :
*********************************************************************/
int32 IFX_LLDP_StopTimer(uint16 unTimerID)
{
  int32 iRetVal = 0,iLoopVar;
  iRetVal = IFX_TLIB_StopTimer(unTimerID);
  if (iRetVal < 0)
  {
	PRINT("\n IFX_LLDP_StopTimer : failed \n");
  }
  for (iLoopVar = 0; iLoopVar < IFX_LLDP_MAX_TIMER; iLoopVar++)

  {
    if (axLLDPTimer[iLoopVar].unTimerId == unTimerID)

    {
      axLLDPTimer[iLoopVar].unTimerId = 0;
      break;
    }
  }
  return iRetVal;
}

/******************************************************************
*  Function Name    : IFX_LLDP_Timer_Handler
*  Description      : When the timeout happens this will be called
and it will write in to the FIFO.
*  Input Values     :
*  Output Values    : None
*  Return Value     : void
*  Notes            :
 
*********************************************************************/
void
IFX_LLDP_Timer_Handler(x_IFX_LLDP_Timer *pxLLDP_Param)
{
   x_IFX_CM_Msg  cCmMsg;

   pxLLDP_Param->unTimerId =0;

   /*action to be taken here*/
   cCmMsg.eModType = IFX_LLDP_TIMER ;
   cCmMsg.xlldpAgentMsg.ucPort = pxLLDP_Param->xTimerParam.ucPort;
   cCmMsg.xlldpAgentMsg.EventID = pxLLDP_Param->xTimerParam.unIndex;   
   cCmMsg.xlldpAgentMsg.eEventType= pxLLDP_Param->xTimerParam.uiMsgType;

   IFX_LLDP_CMFIFO_Write(&cCmMsg,sizeof(x_IFX_CM_Msg));
}

/******************************************************************
*  Function Name    : IFX_LLDP_InitTimer
*  Description      : Number timers required should be configured using this.
*  Input Values     : Number timers required
*  Output Values    : None
*  Return Value     : void
*  Notes            :
 
*********************************************************************/
int32
IFX_LLDP_InitTimer(uint16 unNum)
{
  int32 iRetVal = 0;
  iRetVal = IFX_TLIB_TimersInit(unNum);
  if (iRetVal < 0)
  {
	PRINT("\n IFX_LLDP_InitTimer : failed \n");
  }
  return iRetVal;
}
/******************************************************************
*  Function Name    : IFX_LLDP_DeleteTimer
*  Description      : deletes Timers for LLDP.
*  Input Values     : Number timers required
*  Output Values    : None
*  Return Value     : void
*  Notes            :
 
*********************************************************************/
void
IFX_LLDP_DeleteTimer(void)
{
 IFX_TLIB_TimersDelete();
  return ;
}
