/**************************************************************************
 **   FILE NAME       : ifx_lldp_defs.h
 **   PROJECT         : INCA IP Phone 
 **   MODULES         : Common voip defintions
 **   SRC VERSION     : V0.1
 **   DATE            : 15-06-2005
 **   AUTHOR          : Supreet M S, Awanish G, Pavan G M.
 **   DEPENDENCIES    : ifx_common_defs.h
 **   DESCRIPTION     :
 **   FUNCTIONS       :
 **   COMPILER        : gcc
 **   REFERENCE       : Coding guide lines for VSS ,
 **
 **   COPYRIGHT       : Copyright © 2004 Infineon Technologies AG
 **                     St. Martin Strasse 53; 81669 München, Germany
 **                     Any use of this Software is subject to the conclusion
 **                     of a respective License Agreement.Without such a
 **                     License Agreement no rights to the Software are granted.
 **  Version Control Section  **
 **   $Author$
 **   $Date$
 **   $Revisions$
 **   $Log$       Revision history
***********************************************************************/
#ifndef __IFX_LLDP_DEFS_H__
#define __IFX_LLDP_DEFS_H__

#define IFX_LLDP_IF_NAMESIZE 255

typedef enum
{
  IFX_LLDP_CHASSIS_ID = 1,
  IFX_LLDP_PORT_ID = 2,
  IFX_LLDP_SYSTEM_CAPABILITIES = 4,
  IFX_LLDP_TIME_TO_LIVE =8,
  IFX_LLDP_PORT_VLAN_ID = 0x10,
  IFX_LLDP_PORT_AND_PROTOCOL_VLAN_ID = 0x20,
  IFX_LLDP_VLAN_NAME = 0x40,
  IFX_LLDP_PROTOCOL_IDENTITY =0x80,
  IFX_LLDP_MAC_PHY_CONFIGURATION_STATUS = 0x100,
  IFX_LLDP_MED_CAPABILITIES = 0x200,
  IFX_LLDP_NETWORK_POLICY = 0x400,
  IFX_LLDP_LOCATION_IDENTIFICATION = 0x2000,
  IFX_LLDP_EXTENDED_POWER_VIA_MDI = 0x800,
  IFX_LLDP_END_OF_LLDPDU =0x1000
}e_IFX_LLDP_TLV;

/* This structure contains information related to Chassis Id of a system */
typedef struct {
  uint8 uiSubType;
  uchar8 ucChassisId[255];
} x_IFX_LLDP_ChassisId; 

/* This structure contains information related to Port Id of a system */
typedef struct {
  uint8 uiSubType;
  uchar8 ucPortId[255];
}x_IFX_LLDP_PortId; 

/* This structure stores the System Capabilities TLV related information */
typedef struct {
  uint16 unSysCapabilities;
  uint16 unEnabledCapabilities;
}x_IFX_LLDP_SystemCapabilities;

/* This enum defines all the capabilities that define the primary function(s)
   of a system */
typedef enum {
  IFX_LLDP_OTHER = 0x01,
  IFX_LLDP_REPEATER =0x02,
  IFX_LLDP_BRIDGE= 0x04,
  IFX_LLDP_WLANA= 0x08,
  IFX_LLDP_ROUTER= 0x10,
  IFX_LLDP_TELEPHONE = 0x20,
  IFX_LLDP_CABLEDEV = 0x40,
  IFX_LLDP_STATIONONLY=0x80,
} e_IFX_LLDP_SystemCapabilities;

/* This structure stores the MAC/PHY Configuration/Status TLV related 
   information which has to be updated in MIB */
typedef struct {
  boolean bAutoNegSupported;
  boolean bAutoNegEnabled;
  uint16 unAutoNegAdvCap;
  uint16 unOperMauType;
} x_IFX_LLDP_MacPhyConfigStatus;

/* This enum defines all possible PMD auto-negotiation advertised capabilities
   used in /PHY Configuration/Status TLV */
typedef enum {
  IFX_LLDP_BOTHER = 0,
  IFX_LLDP_B10BASET,
  IFX_LLDP_B10BASETFD,
  IFX_LLDP_B100BASET4,
  IFX_LLDP_B100BASETX,
  IFX_LLDP_B100BASETXFD,
  IFX_LLDP_B100BASET2,
  IFX_LLDP_B100BASET2FD,
  IFX_LLDP_BFDXPAUSE,
  IFX_LLDP_BFDXAPAUSE,
  IFX_LLDP_BFDXSPAUSE,
  IFX_LLDP_BFDXBPAUSE,
  IFX_LLDP_B1000BASEX,
  IFX_LLDP_B1000BASEXFD,
  IFX_LLDP_B1000BASET,
  IFX_LLDP_B1000BASETFD
}e_IFX_LLDP_IfMauAutoNegCapAdvertisedBits;

/* This structure stores the LLDP-MED Capabilities TLV related information 
   which has to be updated in MIB */
typedef struct {
  uint16 unCapSupported;
  uint8 ucDeviceType;
}x_IFX_LLDP_MedCapabilities;

/* This enum defines all types of devices such as Network Connectivity Device, 
   Endpoint Device */
typedef enum {
  IFX_LLDP_NOTDEFINED = 0,
  IFX_LLDP_CLASSI,
  IFX_LLDP_CLASSII,
  IFX_LLDP_CLASSIII,
  IFX_LLDP_NETWORKCONNECTIVITY
}e_IFX_LLDP_DeviceType;

/* This structure stores the Network Policy TLV related information which
   has to be updated in MIB */
typedef struct {
  uint8 ucAppType;
  boolean bUnknownFlag;
  boolean bTaggedFlag;
  uint16 unVLanId;
  uint8 ucPriority;
  uint8 ucDscpValue;	
}x_IFX_LLDP_NetworkPolicyTlv;

typedef struct {
  uint8 uiNoOfNetworkPolicyTlvs;
  x_IFX_LLDP_NetworkPolicyTlv xNetworkPolicyArray[IFX_LLDP_MAXNETWORKTLVS];
}x_IFX_LLDP_NetworkPolicy;

typedef struct {
    uint8 dataFormat;
    uint8 locationId[256];
} x_IFX_LLDP_LocationIdentification;


/* This structure stores the Extended Power-via-MDI TLV related information
   which has to be updated in MIB */
typedef struct {
  uint8 ucPowerType;
  uint8 ucPowerSource;
  uint8 ucPowerPriority;
  uint16 ucPowerValue;
}x_IFX_LLDP_ExtendedPower;


/* This structure stores the Port VLAN ID TLV related 
		information which has to be updated in the MIB */
typedef struct {
	uint16 uiPortVlanId;
}x_IFX_LLDP_PortVlanId;

/* This structure stores the Port And Protocol VLAN ID TLV related 
		information which has to be updated in the MIB */
typedef struct {
  uint8 uiProtoVlanSupported;
  uint8 uiProtoVlanEnabled;
	uint16 uiProtoVlanId;
}x_IFX_LLDP_PortAndProtocolVlanId;

/* This structure stores the VLAN Name TLV related 
		information which has to be updated in the MIB */
typedef struct {
  uint16 uiVlanId;
  uint8 uiVlanNameLength;
	uint8 uiaVlanName[32];
}x_IFX_LLDP_VlanName;

/* This structure stores the Protocol Identity TLV related 
		information which has to be updated in the MIB */
typedef struct {
  uint8 uiProtoIdLength;
  uint8 uiProtoId[255];
}x_IFX_LLDP_ProtocolIdentity;

/* This enum defines types of LLDP-MED device transmitting LLDPDU wrt
   power capabilities */
typedef enum {
  IFX_LLDP_PSEDEVICE = 0,
  IFX_LLDP_PDDEVICE
}e_IFX_LLDP_ExtendedPowerType;

/* This enum defines all types of power sources being utilized by a PD 
   device */
typedef enum {
  IFX_LLDP_PDSOURCEUNKNOWN = 0,
  IFX_LLDP_PSE,
  IFX_LLDP_LOCAL,
  IFX_LLDP_PSEANDLOCAL
} e_IFX_LLDP_ExtendedPowerPdSource;

/* This enum definess all types the power sources being utilized by a
   PSE device */
typedef enum {
  IFX_LLDP_PSESOURCEUNKNOWN = 0,
  IFX_LLDP_PRIMARY,
  IFX_LLDP_BACKUP,
  IFX_LLDP_POWERSOURCERESERVED
} e_IFX_LLDP_ExtendedPowerPseSource;

/* This enum value represents the priority of the PD type device to the 
   power being supplied by the PSE type device, or the power priority 
   associated with the PSE type device's port that is sourcing the power 
   via MDI */
typedef enum {
  IFX_LLDP_POWERPRIORITYUNKNOWN = 0,
  IFX_LLDP_CRITICAL,
  IFX_LLDP_HIGH,
  IFX_LLDP_LOW,
  IFX_LLDP_POWERPRIORITYRESERVED
} e_IFX_LLDP_ExtendedPowerPriority;

/* This enum defines all types of adminStatus values as defined in 802.1 AB 
   specification */
typedef enum {
  IFX_LLDP_DISABLED = 0,
  IFX_LLDP_ENABLED_TX_ONLY ,
  IFX_LLDP_ENABLED_RX_ONLY,
  IFX_LLDP_ENABLED_RXTX
}e_IFX_LLDP_AdminStatus;

/* This structure defines the local LLDP configuration parameters. Refer to 
   Table - 11.1 in 802.1 AB spec */
typedef struct {
  uint8 ucAdminStatus;
  uint16 unReinitDelay;
  uint16 unMsgTxHold;
  uint16 unMsgTxInterval;
  uint16 unTxDelay;
  uint32 uiMedFastStartRepeatCount;
} x_IFX_LLDP_ConfigCfg;

/* This structure is used to store supported TLVs information */
typedef struct {
  uint32 ucPortConfigTlvTxEnable;
  uint16 unManAddrPortsTxEnable;
} x_IFX_LLDP_TlvSelectionCfg;

/* This structure defines all statistical information related to the
   functioning of LLDP Agent. Refer to 802.1 AB, section 10.5.2 for details */
typedef struct {
  uint32 ulStatsAgeoutsTotal;
  uint32 ulStatsFramesDiscardedTotal;
  uint32 ulStatsFramesInErrorsTotal;
  uint32 ulStatsFramesInTotal;
  uint32 ulStatsFramesOutTotal;
  uint32 ulStatsTLVsDiscardedTotal;
  uint32 ulStatsTLVsUnrecognizedTotal;
}x_IFX_LLDP_StatsCfg;

/* This structure is used to store local TLV data */
typedef struct {
  x_IFX_LLDP_ChassisId xChassisId;
  x_IFX_LLDP_PortId xPortId;	
  x_IFX_LLDP_SystemCapabilities xSysCap;
  x_IFX_LLDP_PortVlanId xPortVlanId;
  x_IFX_LLDP_PortAndProtocolVlanId xPortProtoVlan;
  x_IFX_LLDP_VlanName xVlanName;
  x_IFX_LLDP_ProtocolIdentity xProtoId;
  x_IFX_LLDP_MacPhyConfigStatus xMacPhy;
  x_IFX_LLDP_MedCapabilities xMedCap;	
  x_IFX_LLDP_NetworkPolicy xNetworkPolicy;
  x_IFX_LLDP_LocationIdentification xLocationIdentification;
  x_IFX_LLDP_ExtendedPower xExtPower;
} x_IFX_LLDP_TlvData;

typedef x_IFX_LLDP_TlvData x_IFX_LLDP_LocalSystemCfg;

/* This structure is used to store destination information and remote 
   LLDP data */
typedef struct {
  uint8 uiaMacAddress[6];
  uchar8 ucMsap[511];
  x_IFX_LLDP_TlvData xRemoteMib;
  uint8 ucFrame[IFX_LLDP_MAX_FRAME_SIZE];
} x_IFX_LLDP_RemoteSystem;

/* This structure stores information of all remote LLDP entities and their 
   LLDP data */
typedef struct {
  uint32 uiNoOfEntries;
  x_IFX_LLDP_RemoteSystem  axRemoteMibData[IFX_LLDP_MAX_REMOTE_MIB_PER_PORT];
} x_IFX_LLDP_RemoteSystemCfg;
  
/* This structure store the status of the remote LLDP MIB */
typedef struct {
  uint32 uiConfigRemoteEntries;
  uint32 uiCurrentRemoteEntries;  
}x_IFX_LLDP_MiscellaneousCfg;

/* This information stores full information related to a port (LAN or PC) */
typedef struct {
  char8 IfrName[IFX_LLDP_IF_NAMESIZE];
  uchar8 IfrIndex;
  uchar8 ucPortIndex;
  uchar8 ucPortType;/*PC or LAN*/
  x_IFX_LLDP_ConfigCfg xConfigCfg;
  x_IFX_LLDP_TlvSelectionCfg xTlvSelectionCfg;
  x_IFX_LLDP_LocalSystemCfg xLocalSystemCfg;
}x_IFX_LLDP_PortCfg;

/* This is the root storage structure in the CM hierarchy. It in turn stores 
   all CM data in it */
typedef struct{
  e_IFX_LLDP_DeviceType eDevType;
  uchar8 ucNumPorts;
  uint32 uiTlvSupport;
  uint32 uiNoOfRemoteEntries;
  x_IFX_LLDP_StatsCfg xStatsCfg;
  x_IFX_LLDP_RemoteSystemCfg xRemoteSystemCfg;
  x_IFX_LLDP_MiscellaneousCfg xMiscellaneousCfg;
  /*
   * OP - Cannot have refernces to another shared region in first
   *      this doesn't work across two processes
   *      Use global pxSheardmemPortPtr instead
   *		x_IFX_LLDP_PortCfg *pxPortCfg;
   */
}x_IFX_LLDP_DB;

#endif /* __IFX_LLDP_DEFS_H__ */
